@@ -9,11 +9,13 @@ import Accessors: setindex, delete, insert
 @inline insert(obj::StaticVector{<:Any,ET}, l::IndexLens, val::T) where {ET,T} = StaticArrays.insert(similar_type(typeof(obj), promote_type(ET, T))(obj), only(l.indices), val)
 @inline insert(obj::StaticVector{<:Any,T}, l::IndexLens, val::T) where {T} = StaticArrays.insert(obj, only(l.indices), val)
 
-Accessors.set(obj::StaticVector, ::Type{Tuple}, val::Tuple) = constructorof(typeof(obj))(val...)
+Accessors.set(obj::StaticVector, ::Type{Tuple}, val::Tuple) = constructorof(typeof(obj))(val)
 Accessors.set(obj::Tuple, ::Type{<:StaticVector}, val::StaticVector) = Tuple(val)
 
 Accessors.getall(obj::StaticArray, ::Elements) = Tuple(obj)
-Accessors.setall(obj::StaticArray, ::Elements, vs::AbstractArray) = constructorof(typeof(obj))(vs...)  # just for disambiguation
-Accessors.setall(obj::StaticArray, ::Elements, vs) = constructorof(typeof(obj))(vs...)
+# avoid splatting when possible, only use it with AbstractArray input because StaticArray construction isn't defined otherwise:
+Accessors.setall(obj::StaticArray, ::Elements, vs::AbstractArray) = constructorof(typeof(obj))(vs...)
+Accessors.setall(obj::StaticArray, ::Elements, vs::StaticArray) = constructorof(typeof(obj))(vs)
+Accessors.setall(obj::StaticArray, ::Elements, vs::Tuple) = constructorof(typeof(obj))(vs)
 
 end
